ConstructMultiOption class final

Inheritance

Constructors

ConstructMultiOption({required String name, required String help, bool hide = false, String? abbr, String? valueHelp})
const

Properties

abbr String?
final
hashCode int
The hash code for this object.
no setterinherited
help String
finalinherited
hide bool
finalinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueHelp String?
final

Methods

declare(ArgParser parser) → void
Adds this flag to parser. Called for both the outer and inner command.
override
forward(ArgResults results, List<String> out) → void
Appends this flag to out if it was explicitly passed.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited