RoutesHandler class

Mixed-in types

Constructors

RoutesHandler({required FileSystem fs, required String rootPath, required Analyzer analyzer})

Properties

analyzer → Analyzer
final
fs → FileSystem
final
hashCode → int
The hash code for this object.
no setterinherited
rootPath → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

errors() → Future<List<(String, List<AnalysisError>)>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse() → Future<MetaServer>
rootOf(String path) → Future<Directory>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited