CreateCommandMixin mixin

Mixin applications

Properties

componentName → String
no setter
config → CliConfig
no setter
directory → String
The directory where the component will be created.
no setter
fileName → String
no setter
force → bool
no setter
fs → FileSystem
no setter
hashCode → int
The hash code for this object.
no setterinherited
logger → Logger
no setter
root → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

content() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prompt() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited