ContractChange class

One difference between a pinned manifest and a current one.

Constructors

ContractChange({required ContractSeverity severity, required String route, required String description})
const

Properties

description → String
final
hashCode → int
The hash code for this object.
no setterinherited
isBreaking → bool
no setter
route → String
GET /api/users/:id, or manifest for whole-file differences.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → ContractSeverity
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited