ServerAppObservers class

Mixed-in types

Constructors

ServerAppObservers()

Properties

extractors → List<ExtractImport?>
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
hasObservers → bool
no setter
imports → List<ServerImports?>
no setteroverride
mimics ↔ List<ServerMimic>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
types ↔ List<ServerTypeReference>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packageImports() → Iterable<String>
inherited
pathImports() → Iterable<String>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited