ServerChildRoute class

Implemented types
Mixed-in types

Constructors

ServerChildRoute({required ServerType returnType, required ServerStatusCode? httpCode, required ServerMimic? redirect, required String method, required String path, required ServerRouteAnnotations annotations, required String handlerName, required List<ServerParam> params, required MetaWebSocketMethod? webSocket, required bool isSse})
ServerChildRoute.fromMeta(MetaMethod method)
factory

Properties

annotations → ServerRouteAnnotations
final
extractors → List<ExtractImport?>
no setteroverride
handlerName → String
final
hashCode → int
The hash code for this object.
no setterinherited
httpCode → ServerStatusCode?
final
imports → List<ServerImports?>
no setteroverride
isSse → bool
final
isWebSocket → bool
no setter
method → String
final
params → List<ServerParam>
final
path → String
final
pipes → List<ServerPipe>
no setteroverride
redirect → ServerMimic?
final
reflects → Iterable<ServerReflect>
no setter
returnType → ServerType
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webSocket → MetaWebSocketMethod?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packageImports() → Iterable<String>
inherited
pathImports() → Iterable<String>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited