ServerParentRoute class

Implemented types
Mixed-in types

Constructors

ServerParentRoute({required String className, required ServerImports importPath, required String routePath, required List<ServerChildRoute> routes, required List<ServerParam> params, required ServerRouteAnnotations annotations, required int index, required InstanceType type, List<MetaConsumer> consumers = const []})
ServerParentRoute.fromMeta(MetaRoute parentRoute, int index)
factory

Properties

annotations → ServerRouteAnnotations
final
className → String
final
consumers → List<MetaConsumer>
@Consumes handlers on this controller.
final
extractors → List<ExtractImport?>
no setteroverride
fileName → String
no setter
handlerName → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
importPath → ServerImports
final
imports → List<ServerImports?>
no setteroverride
index → int
final
params → List<ServerParam>
final
pipes → List<ServerPipe>
no setteroverride
reflects → Iterable<ServerReflect>
no setter
routePath → String
final
routes → List<ServerChildRoute>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → InstanceType
final
variableName → String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packageImports() → Iterable<String>
inherited
pathImports() → Iterable<String>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited