server/makers/part_files/lifecycle_components/utils/sequential_component_content library

Functions

sequentialComponentContent(ServerLifecycleComponent component, String formatter(Spec), {required String className, required String interfaceName, required String resultType, required String methodName, required List<ServerLifecycleComponentMethod> methods, required String listName, required String itemName, required String shortCircuitOn, required String fallthrough}) String
Builds the class for a lifecycle role that runs a sequence of component methods and returns early on the first short-circuiting result.