exitCode property
int?
get
exitCode
The code the process exited with, or null while it is still running.
Implementation
int? get exitCode => _exitCode;
The code the process exited with, or null while it is still running.
int? get exitCode => _exitCode;