scrollToLive method
void
scrollToLive()
Snaps the pane back to the newest line and re-sticks it there.
Implementation
void scrollToLive() {
if (_scrollTop == null) return;
_scrollTop = null;
notifyListeners();
}
Snaps the pane back to the newest line and re-sticks it there.
void scrollToLive() {
if (_scrollTop == null) return;
_scrollTop = null;
notifyListeners();
}