scrollTop property
int?
get
scrollTop
Where the pane's top visible row is, or null while it follows the tail.
Implementation
int? get scrollTop => _scrollTop;
Where the pane's top visible row is, or null while it follows the tail.
int? get scrollTop => _scrollTop;