utils/package_config_resolution library

Functions

findPackageConfigPath(Directory directory) Future<String?>
Finds the nearest .dart_tool/package_config.json by walking up from the project root of directory.
loadProjectPackageConfig(Directory directory) Future<PackageConfig?>
Loads the package configuration for directory, if one exists.
relativePackageUri(Package package) String
Returns the package URI root path relative to the package root directory.
resolvePackageConfigFile(Directory directory) Future<File>
Resolves the package config file for directory.