ContractReport class
The result of comparing a pinned manifest against a current one.
Constructors
-
ContractReport(List<
ContractChange> changes) -
const
Properties
-
breaking
→ List<
ContractChange> -
no setter
-
changes
→ List<
ContractChange> -
final
-
compatible
→ List<
ContractChange> -
no setter
- hasBreaking → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited